@@ -2,14 +2,14 @@
 Lambda Gateway.
 
 Usage:
-  lgw gw-deploy [--verbose] --config-file=<cfg>
-  lgw gw-undeploy [--verbose] --config-file=<cfg>
-  lgw domain-add [--verbose] --config-file=<cfg>
-  lgw domain-remove [--verbose] --config-file=<cfg>
-  lgw lambda-deploy [--verbose] --config-file=<cfg> --lambda-file=<zip>
+  lgw gw-deploy [--verbose] [--config-file=<cfg>]
+  lgw gw-undeploy [--verbose] [--config-file=<cfg>]
+  lgw domain-add [--verbose] [--config-file=<cfg>]
+  lgw domain-remove [--verbose] [--config-file=<cfg>]
+  lgw lambda-deploy [--verbose] [--config-file=<cfg>] [--lambda-file=<zip>]
   lgw lambda-invoke [--verbose] --lambda-name=<name> [--payload=<json>]
   lgw lambda-delete [--verbose] --lambda-name=<name>
-  lgw lambda-archive [--verbose] --config-file=<cfg>
+  lgw lambda-archive [--verbose] [--config-file=<cfg>]
 
 Options:
   -h --help             Show this screen.
@@ -22,6 +22,7 @@ Options:
 '''
 
 from os import path, makedirs
+from sys import argv
 import json
 from logging import info, debug, error
 from everett.manager import ConfigManager, ConfigOSEnv, ConfigDictEnv
@@ -34,16 +35,28 @@ from lgw.api_gateway import create_rest_api, delete_rest_api
 from lgw.api_gateway_domain import add_domain_mapping, remove_domain_mapping
 from lgw.lambda_util import deploy_function, invoke_function, delete_function
 from lgw.lambda_bundle import build_lambda_archive
+from lgw.settings import dump
+
+
+def handle_deploy_lambda(config):
+    return handle_deploy_lambda(None, config)
 
 
 def handle_deploy_lambda(file, config):
-    info('handle_deploy_lambda() called with file [%s]' % file)
+    if file:
+        info(f'handle_deploy_lambda() called with file [{file}]')
+    else:
+        info(
+            'handle_deploy_lambda() called with s3://%s/%s'
+            % (config('aws_lambda_archive_bucket'), config('aws_lambda_archive_key'))
+        )
 
-    if not path.isfile(file):
-        raise FileNotFoundError('ERROR: Lambda zip file not found at location: [%s]' % file)
+    if file:
+        if not path.isfile(file):
+            raise FileNotFoundError('ERROR: Lambda zip file not found at location: [%s]' % file)
 
-    if not file.endswith('.zip'):
-        raise FileNotFoundError('ERROR: Lambda file expected to be in ZIP format.')
+        if not file.endswith('.zip'):
+            raise FileNotFoundError('ERROR: Lambda file expected to be in ZIP format.')
 
     lambda_arn = deploy_function(
         file,
@@ -120,6 +133,7 @@ def handle_delete_lambda(name):
 
 
 def handle_deploy_api_gateway(config):
+    binary_types = []
     if config('aws_api_binary_types'):
         binary_types = config('aws_api_binary_types').split(',')
 
@@ -188,8 +202,12 @@ def app(args, config):
     if args.get('domain-remove'):
         return handle_remove_domain(config)
     if args.get('lambda-deploy'):
-        file = path.abspath(args.get('--lambda-file'))
-        return handle_deploy_lambda(file, config)
+        file_arg = args.get('--lambda-file')
+        if file_arg:
+            file = path.abspath(file_arg)
+            return handle_deploy_lambda(file, config)
+        else:
+            return handle_deploy_lambda(config)
     if args.get('lambda-invoke'):
         name = args.get('--lambda-name')
         payload = args.get('--payload', None)
@@ -207,16 +225,22 @@ def load_config(config_file):
     # python-dotenv enables interpolation of values in config file
     # from the environment or elsewhere in the config file using
     # POSIX variable expansion
+
+    config_wrappers = []
+    config_wrappers.append(ConfigOSEnv())
+
     local_conf = dotenv_values(find_dotenv())
-    project_conf = dotenv_values(dotenv_path=config_file)
-    config = ConfigManager(
-        [
-            ConfigOSEnv(),
-            ConfigDictEnv(local_conf),
-            ConfigDictEnv(project_conf),
-            ConfigDictEnv(settings.defaults()),
-        ]
-    )
+    config_wrappers.append(ConfigDictEnv(local_conf))
+
+    if config_file:
+        config_file_path = path.abspath(config_file)
+        project_conf = dotenv_values(dotenv_path=config_file_path)
+        config_wrappers.append(ConfigDictEnv(project_conf))
+
+    config_wrappers.append(ConfigDictEnv(settings.defaults()))
+
+    config = ConfigManager(config_wrappers)
+
     return config
 
 
@@ -225,13 +249,17 @@ def main():
     configure_logging(args.get('--verbose'))
     config_file = args.get('--config-file', None)
     if config_file:
-        config_file = path.abspath(config_file)
-    debug(f'Reading config from file {config_file}')
+        debug(f'Reading config from file {config_file}')
 
     config = load_config(config_file)
+    if args.get('--verbose'):
+        debug(f'All config values:')
+        dump(config)
 
     app(args, config)
 
 
 if __name__ == '__main__':
+    if '--verbose' in argv:
+        print(argv)
     main()
